#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.analysis_interfaces.analysis_sensor import AnalysisSensor


class AnalysisGlobalSensor(AnalysisSensor):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATAnalysisInterfaces.AnalysisEntity
                |                         CATAnalysisInterfaces.AnalysisSensor
                |                             AnalysisGlobalSensor
                | 
                | Represent the analysis global sensor.
                | 
                | This object is a kind of AnalysisSensor based on analysis feature global
                | results. For example, extract the Energy value of a solution.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_global_sensor = com_object

    def get_identifier(self, o_type_bstr: str, o_sub_type_bstr: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetIdentifier(CATBSTR oTypeBSTR,
                | CATBSTR oSubTypeBSTR)
                | 
                |     Retreives the Physical type and sub physical type that will be computed by
                |     the sensor.
                | 
                |     Parameters:
                | 
                |         oTypeBSTR
                |             The physical type identifier. 
                |         oSubTypeBSTR
                |             The "sub" physical type identifier.

        :param str o_type_bstr:
        :param str o_sub_type_bstr:
        :rtype: None
        """
        return self.analysis_global_sensor.GetIdentifier(o_type_bstr, o_sub_type_bstr)

    def set_identifier(self, i_type_bstr: str, i_sub_type_bstr: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetIdentifier(CATBSTR iTypeBSTR,
                | CATBSTR iSubTypeBSTR)
                | 
                |     Sets the Physical type and sub physical type that will be computed by the
                |     sensor.
                | 
                |     Parameters:
                | 
                |         iTypeBSTR
                |             The physical type identifier. 
                |         iSubTypeBSTR
                |             The "sub" physical type identifier.

        :param str i_type_bstr:
        :param str i_sub_type_bstr:
        :rtype: None
        """
        return self.analysis_global_sensor.SetIdentifier(i_type_bstr, i_sub_type_bstr)

    def __repr__(self):
        return f'AnalysisGlobalSensor(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.eno_cd5_interfaces.cd5_property import CD5Property
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class CD5Properties(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     CD5Properties
                | 
                | Represents a collection of all the properties of an ENOVIA V6
                | object.
                | 
                | Role: It represents all the properties of a given object/document already saved
                | into ENOVIA. The purpose of this interface is to get a collection of an ENOVIA
                | V6 object properties. The properties are accessible through Edit/Properties
                | menu item after user has clicked the ‘More…’ button It is managed by
                | CD5Engine.
                | 
                | Example:
                | 
                |       The following example indicates how to retrieve CD5Properties from ENOVIA
                |       V6 Integration Engine.
                |      
                | 
                |      Dim objCD5Properties As CD5Properties
                |      'To get properties of regular documents
                |      Set objCD5Properties = oCD5Engine.GetPropertiesOfDocument(objCATIADocument)
                |      'To get properties of Embedded Component
                |      Set objCD5Properties = oCD5Engine.GetPropertiesOfDocument(objCATIADocument, "Embedded_Component_Name")
                |
                | See also:
                |     CD5Engine, CD5Property
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=CD5Property)
        self.cd5_properties = com_object

    def item(self, i_index: cat_variant) -> CD5Property:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As CD5Property
                | 
                |     Returns ENOVIA V6 object property specified by 1 based index. That is, 1th
                |     index is the first property ergo last property is (Total Count)th
                |     Index
                | 
                |     Throws:
                | 
                |         -1641847650 : Connection to ENOVIA V6 is necessary to intialize this option.
                | 
                |     Example:
                | 
                |           The following example shows how to retrieve a single property from
                |           the collection of all properties.
                |
                |          Dim objCD5Property As CD5Property
                |          Set objCD5Property = objCD5Properties.Item(1)

        :param cat_variant i_index:
        :rtype: CD5Property
        """
        return CD5Property(self.cd5_properties.Item(i_index))

    def __repr__(self):
        return f'CD5Properties(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SchAppDeleteCheck(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppDeleteCheck
                | 
                | Manage the deletion of a schematic object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_delete_check = com_object

    def app_get_delete_warning(self, o_caption: str, o_message: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppGetDeleteWarning(CATBSTR oCaption,
                | CATBSTR oMessage)
                | 
                |     Returns the caption and message text to be used as a warning for the delete
                |     operation.
                | 
                |     Parameters:
                | 
                |         oCaption
                |             Pointer to a CATUnicode string used for the caption of the message
                |             box. 
                |         oMessage
                |             Pointer to a CATUnicode string used as the warning message.
                |             
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppDeleteCheck
                |          Dim strVar1 As String
                |          Dim strVar2 As String
                |           ...
                |          objThisIntf.AppGetDeleteWarningstrVar1,strVar2

        :param str o_caption:
        :param str o_message:
        :rtype: None
        """
        return self.sch_app_delete_check.AppGetDeleteWarning(o_caption, o_message)

    def app_ok_to_delete_without_warning(self, o_ok: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppOkToDeleteWithoutWarning(boolean oOk)
                | 
                |     Reports if a warning message should be issued before deleting the
                |     object.
                |     Example:A Logical Line with members cannot be deleted without
                |     complications. Its members must also be deleted for model integrity. A Logical
                |     Line with members would return FALSE in this case.
                | 
                |     Parameters:
                | 
                |         oOK
                |             Pointer to the CATBoolean to receive the ok. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppDeleteCheck
                |          Dim bVar1 As boolean
                |           ...
                |          objThisIntf.AppOkToDeleteWithoutWarningbVar1

        :param bool o_ok:
        :rtype: None
        """
        return self.sch_app_delete_check.AppOkToDeleteWithoutWarning(o_ok)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_ok_to_delete_without_warning'
        # # vba_code = """
        # # Public Function app_ok_to_delete_without_warning(sch_app_delete_check)
        # #     Dim oOk (2)
        # #     sch_app_delete_check.AppOkToDeleteWithoutWarning oOk
        # #     app_ok_to_delete_without_warning = oOk
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchAppDeleteCheck(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SchAppCntrColour(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppCntrColor
                | 
                | Manage graphical representation of schematic connector.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_cntr_colour = com_object

    def app_get_connector_colour_by_type(self, o_colour: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppGetConnectorColorByType(long oColor)
                | 
                |     Specify the connector color of this connector type.
                | 
                |     Parameters:
                | 
                |         oColor
                |             Application connector color for "this" connector type. Please refer
                |             to CATColorName.h of Visualization FW. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppCntrColor
                |          Dim intVar1 As Integer
                |           ...
                |          objThisIntf.AppGetConnectorColorByTypeintVar1

        :param int o_colour:
        :rtype: None
        """
        return self.sch_app_cntr_colour.AppGetConnectorColorByType(o_colour)

    def __repr__(self):
        return f'SchAppCntrColour(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_boundary_conditions import ABQBoundaryConditions
from pycatia.abq_automation_interfaces.abq_loads import ABQLoads
from pycatia.abq_automation_interfaces.abq_step import ABQStep


class ABQIAABQSteadyStateLinDynStepBasicVB(ABQStep):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQStep
                |                         ABQIAABQSteadyStateLinDynStepBasicVB
                | 
                | Interface representing xxx.
                | 
                | Role: Components that implement ABQIAABQSteadyStateLinDynStepBasic are
                | ...
                | 
                | Do not use the ABQIAABQSteadyStateLinDynStepBasic interface for such and such
                | ClassReference, Class#MethodReference, #InternalMethod...
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abqiaabq_steady_state_lin_dyn_step_basic_vb = com_object

    @property
    def boundary_conditions(self) -> ABQBoundaryConditions:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BoundaryConditions() As ABQBoundaryConditions (Read
                | Only)
                | 
                |     Returns the ABQBoundaryConditions container associated with the
                |     step.
                | 
                |     Example:
                |         This example retrieves the ABQBoundaryConditions container
                |         abqBCs.
                | 
                |          Dim abqSSDStep As ABQSteadStateStep 
                |          Dim abqBCs As ABQBoundaryConditions
                |          Set abqBCs = abqSSDStep.BoundaryConditions

        :rtype: ABQBoundaryConditions
        """

        return ABQBoundaryConditions(self.abqiaabq_steady_state_lin_dyn_step_basic_vb.BoundaryConditions)

    @property
    def description(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Description() As CATBSTR
                | 
                |     Returns or sets the description of the Abaqus steady state dynamic
                |     step.
                | 
                |     Returns:
                |         The description of the Abaqus steady state dynamic
                |         step.

        :rtype: str
        """

        return self.abqiaabq_steady_state_lin_dyn_step_basic_vb.Description

    @description.setter
    def description(self, value: str):
        """
        :param str value:
        """

        self.abqiaabq_steady_state_lin_dyn_step_basic_vb.Description = value

    @property
    def interval_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property IntervalType() As short
                | 
                |     Returns or sets Interval Type.
                | 
                |     Returns:
                |         The Interval Type.
                |
                |         Legal values:
                |          1 - Eigenvalue.
                |          2 - Range.
                |
                |         Example:
                |             This example sets the Interval Type as Eigenvalue for
                |             abqSSDStep
                |             abqSSDStep.IntervalType = 1

        :rtype: int
        """

        return self.abqiaabq_steady_state_lin_dyn_step_basic_vb.IntervalType

    @interval_type.setter
    def interval_type(self, value: int):
        """
        :param int value:
        """

        self.abqiaabq_steady_state_lin_dyn_step_basic_vb.IntervalType = value

    @property
    def loads(self) -> ABQLoads:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Loads() As ABQLoads (Read Only)
                | 
                |     Returns the ABQLoads container associated with the step.
                | 
                |     Example:
                |         The following example retrieves the ABQLoads container
                |         abqLoads:
                | 
                |          Dim abqSSDStep As ABQSteadStateStep 
                |          Dim abqLoads As ABQLoads
                |          Set abqLoads = abqSSDStep.Loads

        :rtype: ABQLoads
        """

        return ABQLoads(self.abqiaabq_steady_state_lin_dyn_step_basic_vb.Loads)

    @property
    def scale_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ScaleType() As short
                | 
                |     Returns or sets Scale Type.
                | 
                |     Returns:
                |         The Scale Type.
                |
                |         Legal values:
                |          1 - Logarithmic.
                |          2 - Linear.
                |
                |         Example:
                |             This example sets the Scale Type as Logarithmic for
                |             abqSSDStep
                |             abqSSDStep.ScaleType = 1

        :rtype: int
        """

        return self.abqiaabq_steady_state_lin_dyn_step_basic_vb.ScaleType

    @scale_type.setter
    def scale_type(self, value: int):
        """
        :param int value:
        """

        self.abqiaabq_steady_state_lin_dyn_step_basic_vb.ScaleType = value

    def add_frequency_data_table(
            self,
            i_lwr_frequency: tuple,
            i_upr_frequency: tuple,
            i_nb_points: tuple,
            i_bias: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddFrequencyDataTable(CATSafeArrayVariant
                | iLwrFrequency,
                | CATSafeArrayVariant iUprFrequency,
                | CATSafeArrayVariant iNbPoints,
                | CATSafeArrayVariant iBias)
                | 
                |     Adds a list of frequency, real and imaginary The number of values in all
                |     the four of the parameters must match. If either list contains extra values,
                |     the extra values are discarded.
                | 
                |     Parameters:
                | 
                |         iLwrFrequency
                |             The list of lower frequencies.
                |         iUprFrequency
                |             The list of upper frequencies.
                |         iNbPoints
                |             The list of number of points.
                |         iBias
                |             The list of bias.

        :param tuple i_lwr_frequency:
        :param tuple i_upr_frequency:
        :param tuple i_nb_points:
        :param tuple i_bias:
        :rtype: None
        """
        return self.abqiaabq_steady_state_lin_dyn_step_basic_vb.AddFrequencyDataTable(
            i_lwr_frequency,
            i_upr_frequency,
            i_nb_points,
            i_bias
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_frequency_data_table'
        # # vba_code = """
        # # Public Function add_frequency_data_table(abqiaabq_steady_state_lin_dyn_step_basic_vb)
        # #     Dim iLwrFrequency (2)
        # #     abqiaabq_steady_state_lin_dyn_step_basic_vb.AddFrequencyDataTable iLwrFrequency
        # #     add_frequency_data_table = iLwrFrequency
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_global_damping(self, i_alpha: float, i_beta: float, i_structural: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddGlobalDamping(double iAlpha,
                | double iBeta,
                | double iStructural)
                | 
                |     Returns or sets Global Damping values.
                | 
                |     Returns:
                |         Global Damping values.

        :param float i_alpha:
        :param float i_beta:
        :param float i_structural:
        :rtype: None
        """
        return self.abqiaabq_steady_state_lin_dyn_step_basic_vb.AddGlobalDamping(i_alpha, i_beta, i_structural)

    def __repr__(self):
        return f'ABQIAABQSteadyStateLinDynStepBasicVB(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class PCBArea(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PCBArea

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.pcb_area = com_object

    @property
    def area_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AreaType() As CATBSTR (Read Only)
                | 
                |     Allow to get the Type of a constraint area The possible values are : ROUTE_OUTLINE,
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :rtype: str
        """

        return self.pcb_area.AreaType

    @property
    def height_max(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Heightmax() As double
                | 
                |     Allow to get and set the Height max of the constraint area This property is
                |     valid for the following constraints areas: OTHER_OUTLINE,
                |     PLACE_REGION
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :rtype: float
        """

        return self.pcb_area.Heightmax

    @height_max.setter
    def height_max(self, value: float):
        """
        :param float value:
        """

        self.pcb_area.Heightmax = value

    @property
    def height_min(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Heightmin() As double
                | 
                |     Allow to get and set the Height min of the constraint area This property is
                |     valid for the following constraints areas: PLACE_KEEPOUT
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :rtype: float
        """

        return self.pcb_area.Heightmin

    @height_min.setter
    def height_min(self, value: float):
        """
        :param float value:
        """

        self.pcb_area.Heightmin = value

    @property
    def identifier(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Identifier() As CATBSTR
                | 
                |     Allow to get and set the Identifier of the constraint area This property is
                |     valid for the following constraints areas: OTHER_OUTLINE,
                |     PLACE_REGION
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :rtype: str
        """

        return self.pcb_area.Identifier

    @identifier.setter
    def identifier(self, value: str):
        """
        :param str value:
        """

        self.pcb_area.Identifier = value

    @property
    def layer(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property LAYER() As CATBSTR (Read Only)
                | 
                |     Allow to get the position of a hole The possible values are :
                |     TOP,BOTTOM,BOTH,INNER,ALL It depends on the the type of the constraints
                |     area according to the IDF format This property is valid for the following
                |     constraints areas:
                |     OTHER_OUTLINE,
                |     ROUTING_OUTLINE,
                |     PLACE_OUTLINE,
                |     ROUTE_KEEPOUT,
                |     PLACE_KEEPOUT,
                |     PLACE_REGION,
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :rtype: str
        """

        return self.pcb_area.LAYER

    @property
    def owner(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property OWNER() As CATBSTR
                | 
                |     Allow to get and set the OWNER of the constraint area The possible value
                |     are MCAD,ECAD, UNOWNED
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :rtype: str
        """

        return self.pcb_area.OWNER

    @owner.setter
    def owner(self, value: str):
        """
        :param str value:
        """

        self.pcb_area.OWNER = value

    def __repr__(self):
        return f'PCBArea(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_plant_ship_interfaces.psp_list_of_bstrs import PSPListOfBSTRs
from pycatia.system_interfaces.any_object import AnyObject


class PSPClass(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspClass
                | 
                | Represent Interface to list the start up object classes of an
                | application.
                | Role: Application object classes.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_class = com_object

    @property
    def start_up_connectors(self) -> PSPListOfBSTRs:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StartUpConnectors() As PspListOfBSTRs (Read Only)
                | 
                |     Returns a List of start-up Connector object classes.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspClass
                |          Dim objArg1 As PspListOfBSTRs
                |           ...
                |          Set objArg1 = objThisIntf.StartUpConnectors

        :rtype: PSPListOfBSTRs
        """

        return PSPListOfBSTRs(self.psp_class.StartUpConnectors)

    @property
    def start_up_functions(self) -> PSPListOfBSTRs:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StartUpFunctions() As PspListOfBSTRs (Read Only)
                | 
                |     Returns a List of start-up Function object classes.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspClass
                |          Dim objArg1 As PspListOfBSTRs
                |           ...
                |          Set objArg1 = objThisIntf.StartupFunctions

        :rtype: PSPListOfBSTRs
        """

        return PSPListOfBSTRs(self.psp_class.StartUpFunctions)

    @property
    def start_up_physicals(self) -> PSPListOfBSTRs:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StartUpPhysicals() As PspListOfBSTRs (Read Only)
                | 
                |     Returns a List of start-up physical object classes.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspClass
                |          Dim objArg1 As PspListOfBSTRs
                |           ...
                |          Set objArg1 = objThisIntf.StartupPhysicals

        :rtype: PSPListOfBSTRs
        """

        return PSPListOfBSTRs(self.psp_class.StartUpPhysicals)

    def __repr__(self):
        return f'PSPClass(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class CatalogShmObjectSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         CatalogSHMObjectSettingAtt
                | 
                | Represents the CATIA Sheet Metal Aerospace General setting controller
                | object.
                | Role: The CATIA Sheet Metal Aerospace setting General controller object deals
                | with the setting attributes displayed in the Aerospace Sheet Metal Design
                | General property page. To access this property page:
                | 
                |     Click the Options command in the Tools menu
                |     Click + left of Mechanical Design to unfold the workbench
                |     list
                |     Click General
                | 
                | The Sheet Metal Aerospace General setting controller object can be retrieved as
                | an item of the setting controller collection using its name
                | "CATIStmCatalogSHMObjectSettingCtrl" as follows:
                | 
                |  Dim settingControllers1 As SettingControllers
                |  Set settingControllers1 = CATIA.SettingControllers
                |  Dim CATIAStmCatalogSHMObjectSettingAtt1 As SettingController
                |  Set CATIAStmCatalogSHMObjectSettingAtt1 = settingControllers1.Item("CATIStmCatalogSHMObjectSettingCtrl")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.catalog_shm_object_setting_att = com_object

    @property
    def shm_std_prof_path(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SHMStdProfPath() As CATBSTR
                | 
                |     Returns or sets the SHMStdProfPath setting parameter
                |     value.
                |     Role: The SHMStdProfPath setting parameter stores the path to the CATIA
                |     Catalog file used by the Catalog Browser whenever it is involved in Aerospace
                |     Sheet Metal commands, such as cutout or corner relief.
                |     Legal values: a valid path to a CATIA Catalog file.

        :rtype: str
        """

        return self.catalog_shm_object_setting_att.SHMStdProfPath

    @shm_std_prof_path.setter
    def shm_std_prof_path(self, value: str):
        """
        :param str value:
        """

        self.catalog_shm_object_setting_att.SHMStdProfPath = value

    def get_shm_std_prof_path_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSHMStdProfPathInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the SHMStdProfPath setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.catalog_shm_object_setting_att.GetSHMStdProfPathInfo(io_admin_level, io_locked)

    def set_shm_std_prof_path_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSHMStdProfPathLock(boolean iLocked)
                | 
                |     Locks or unlocks the SHMStdProfPath setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.catalog_shm_object_setting_att.SetSHMStdProfPathLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_shm_std_prof_path_lock'
        # # vba_code = """
        # # Public Function set_shm_std_prof_path_lock(catalog_shm_object_setting_att)
        # #     Dim iLocked (2)
        # #     catalog_shm_object_setting_att.SetSHMStdProfPathLock iLocked
        # #     set_shm_std_prof_path_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'CatalogShmObjectSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_device_interfaces.basic_device import BasicDevice


class D5Device(BasicDevice):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DNBDeviceInterfaces.BasicDevice
                |                         D5Device
                | 
                | Interface representing a D5 Device.
                | 
                | Role: This interface is used to interact with devices that are available in the
                | Device Building workbench. This interfaces is derived from BasicDevice to
                | support specific properties for D5 devices.
                | The following code snippet can be used to obtain a device in a CATProduct
                | document.
                | 
                |    Dim objDevice As BasicDevice
                |    set objDevice = CATIA.ActiveDocument.Product.GetTechnologicalObject("BasicDevice")
                |    Dim objD5Device as D5Device
                |    Set objD5Device = objDevice
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.d5_device = com_object

    def get_linked_device_file(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetLinkedDeviceFile() As CATBSTR
                | 
                |     Get the Linked D5 Device File.
                | 
                |     Parameters:
                | 
                |         oFileName
                |             This will contain the full path to the file (file name and path) to
                |             the D5 device file.

        :rtype: str
        """
        return self.d5_device.GetLinkedDeviceFile()

    def __repr__(self):
        return f'D5Device(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.arrangement_interfaces.arr_nomenclature_tree import ArrNomenclatureTree
from pycatia.arrangement_interfaces.arrangement_product import ArrangementProduct
from pycatia.in_interfaces.workbench import Workbench
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class ArrWorkbench(Workbench):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Workbench
                |                         ArrWorkbench
                | 
                | Returns the Arrangement Workbench.
                | Role: Use this interface to manage the ArrNomenclatureTree object, create
                | Arrangement objects (such as ArrangementArea, ArrangementRun
                | etc).
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.arr_workbench = com_object

    @property
    def arr_nomenclature_tree(self) -> ArrNomenclatureTree:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ArrNomenclatureTree() As ArrNomenclatureTree (Read
                | Only)
                | 
                |     Returns the ArrNomenclatureTree.

        :rtype: ArrNomenclatureTree
        """

        return ArrNomenclatureTree(self.arr_workbench.ArrNomenclatureTree)

    def add_nomenclature_tree(self) -> ArrNomenclatureTree:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddNomenclatureTree() As ArrNomenclatureTree
                | 
                |     This method allows the user to add a nomenclature tree if the
                |     get_ArrNomenclatureTree returns a Return code of E_FAIL. Basically, the
                |     workbench could not locate the startup instance to generate the necessary
                |     NomenclatureTree information.

        :rtype: ArrNomenclatureTree
        """
        return ArrNomenclatureTree(self.arr_workbench.AddNomenclatureTree())

    def convert_arrangement_product_to_product(self, i_arr_product: ArrangementProduct) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ConvertArrangementProductToProduct(ArrangementProduct iArrProduct) As
                | Product
                | 
                |     This method converts an ArrangementProduct back to a
                |     Product.
                | 
                |     Parameters:
                | 
                |         iArrProduct
                |             Input ArrangementProduct to be converted. 
                | 
                |     Returns:
                |         oProduct As CATIAProduct Converted Product. 
                |     See also:
                |         Product

        :param ArrangementProduct i_arr_product:
        :rtype: Product
        """
        return Product(self.arr_workbench.ConvertArrangementProductToProduct(i_arr_product.com_object))

    def convert_product_to_arrangement_product(self, i_product: Product) -> ArrangementProduct:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ConvertProductToArrangementProduct(Product iProduct) As
                | ArrangementProduct
                | 
                |     This method converts a Product to an ArrangementProduct.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             Input Product to be converted. 
                | 
                |     Returns:
                |         oArrProduct Converted ArrangementProduct. 
                |     See also:
                |         Product

        :param Product i_product:
        :rtype: ArrangementProduct
        """
        return ArrangementProduct(self.arr_workbench.ConvertProductToArrangementProduct(i_product.com_object))

    def find_interface(self, i_interface_name: str, i_object: AnyObject) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func FindInterface(CATBSTR iInterfaceName,
                | CATBaseDispatch iObject) As CATBaseDispatch
                | 
                |     This method returns a interface handle as specified by the input interface
                |     name and the input interface handle.
                | 
                |      Dim interfaceFound As AnyObject
                |      Set interfaceFound = CATIAArrWorkbench.FindInterface("InterfaceNameToFind",CATIAProduct_iObject)
                |      
                | 
                |     Parameters:
                | 
                |         iInterfaceName
                |             interface name to search for ("CATIAxxxx") 
                |         iObject
                |             The object to search for the required interface. 
                | 
                |     Returns:
                |         oInterfaceFound interface handle found

        :param str i_interface_name:
        :param AnyObject i_object:
        :rtype: AnyObject
        """
        return self.arr_workbench.FindInterface(i_interface_name, i_object.com_object)

    def __repr__(self):
        return f'ArrWorkbench(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.shape import Shape


class SurfaceBasedShape(Shape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         SurfaceBasedShape
                | 
                | Represents the shapes based on Surface.
                | It is the base object for Split , SewSurface , CloseSurface and ThickSurface
                | shapes.
                | 
                | See also:
                |     Split, SewSurface, CloseSurface, ThickSurface
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.surface_based_shape = com_object

    @property
    def surface(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Surface() As Reference
                | 
                |     Returns or sets the surface.

        :rtype: Reference
        """

        return Reference(self.surface_based_shape.Surface)

    @surface.setter
    def surface(self, value: Reference):
        """
        :param Reference value:
        """

        self.surface_based_shape.Surface = value.com_object

    def __repr__(self):
        return f'SurfaceBasedShape(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class DrawingArrow(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DrawingArrow
                | 
                | Represents a drawing arrow in a drawing view.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.drawing_arrow = com_object

    @property
    def head_symbol(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property HeadSymbol() As CatSymbolType
                | 
                |     Returns or sets symbol type of head side.
                | 
                |     Example:
                |         This example retrieves the symbol type of head side on MyArrow drawing
                |         arrow.
                | 
                |          oSymbol = MyArrow.HeadSymbol

        :return: enum cat_symbol_type
        :rtype: int
        """

        return self.drawing_arrow.HeadSymbol

    @head_symbol.setter
    def head_symbol(self, value: int):
        """
        :param int value: enum cat_symbol_type
        """

        self.drawing_arrow.HeadSymbol = value

    @property
    def head_target(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property HeadTarget() As CATBaseDispatch
                | 
                |     Returns or sets target element of head side.
                | 
                |     Example:
                |         This example retrieves the target element of head side on MyArrow
                |         drawing arrow.
                | 
                |          oTarget = MyArrow.HeadTarget

        :rtype: AnyObject
        """

        return AnyObject(self.drawing_arrow.HeadTarget)

    @head_target.setter
    def head_target(self, value: AnyObject):
        """
        :param AnyObject value:
        """

        self.drawing_arrow.HeadTarget = value

    @property
    def nb_interruption(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property NbInterruption() As long (Read Only)
                | 
                |     Returns the number of interruptions of arrow path.
                | 
                |     Example:
                |         This example retrieves the number of interruptions on MyArrow drawing
                |         arrow.
                | 
                |          oNbInterruption = MyArrow.NbInterruption

        :rtype: int
        """

        return self.drawing_arrow.NbInterruption

    @property
    def nb_point(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property NbPoint() As long (Read Only)
                | 
                |     Returns the number of points of arrow path.
                | 
                |     Example:
                |         This example retrieves the number of points on MyArrow drawing
                |         arrow.
                | 
                |          oNbPoint = MyArrow.NbPoint

        :rtype: int
        """

        return self.drawing_arrow.NbPoint

    @property
    def tail_symbol(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property TailSymbol() As CatSymbolType
                | 
                |     Returns or sets symbol type of tail side.
                | 
                |     Example:
                |         This example retrieves the symbol type of tail side on MyArrow drawing
                |         arrow.
                | 
                |          oSymbol = MyArrow.TailSymbol

        :rtype: int
        """

        return self.drawing_arrow.TailSymbol

    @tail_symbol.setter
    def tail_symbol(self, value: int):
        """
        :param int value:
        """

        self.drawing_arrow.TailSymbol = value

    @property
    def tail_target(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property TailTarget() As CATBaseDispatch
                | 
                |     Returns or sets target element of tail side.
                | 
                |     Example:
                |         This example retrieves the target element of tail side on MyArrow
                |         drawing arrow.
                | 
                |          oTarget = MyArrow.TailTarget

        :rtype: AnyObject
        """

        return AnyObject(self.drawing_arrow.TailTarget)

    @tail_target.setter
    def tail_target(self, value: AnyObject):
        """
        :param AnyObject value:
        """

        self.drawing_arrow.TailTarget = value

    def add_interruption(self,
                         i_first_point_x: float,
                         i_first_point_y: float,
                         i_second_point_x: float,
                         i_second_point_y: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub AddInterruption(double iFirstPointX,
                | double iFirstPointY,
                | double iSecondPointX,
                | double iSecondPointY)
                | 
                |     Add an interruption to an arrow.
                | 
                |     Parameters:
                | 
                |         iFirstPointX
                |             X coordinates of first point. 
                |         iFirstPointY
                |             Y coordinates of first point. 
                |         iSecondPointX
                |             X coordinates of second point. 
                |         iSecondPointY
                |             Y coordinates of second point. 
                |         Example:
                |             This example adds an interruption to MyArrow.
                | 
                |              iFirstPointX = 10.
                |              iFirstPointY = 20.
                |              iSecondPointX = 20.
                |              iSecondPointY = 20.
                |              MyArrow.AddInterruption iFirstPointX, iFirstPointY, iSecondPointX,
                |              iSecondPointY

        :param float i_first_point_x:
        :param float i_first_point_y:
        :param float i_second_point_x:
        :param float i_second_point_y:
        :rtype: None
        """
        return self.drawing_arrow.AddInterruption(i_first_point_x, i_first_point_y, i_second_point_x, i_second_point_y)

    def add_point(self, i_num: int, i_x: float, i_y: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub AddPoint(long iNum,
                | double iX,
                | double iY)
                | 
                |     Add a point to an arrow.
                | 
                |     Parameters:
                | 
                |         iNum
                |             Point number. Point will be inserted at iNum+1 position.
                |             
                |         iX
                |             X coordinates of point to add. 
                |         iY
                |             Y coordinates of point to add. 
                |         Example:
                |             This example adds a point to MyArrow.
                | 
                |              iNum = 1
                |              iX = 10.
                |              iY = 20.
                |              MyArrow.AddPoint iNum, iX, iY

        :param int i_num:
        :param float i_x:
        :param float i_y:
        :rtype: None
        """
        return self.drawing_arrow.AddPoint(i_num, i_x, i_y)

    def get_interruptions(self, o_interruptions: tuple) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetInterruptions(CATSafeArrayVariant oInterruptions) As
                | long
                | 
                |     Get arrow path.
                | 
                |     Parameters:
                | 
                |         oInterruptions
                |             List of interruptions coordinates (X1,Y1,X2,Y2,.....Xn,Yn).
                |             
                | 
                |     Returns:
                |         oNbInterruptions Number of interruptions. 
                |     Example:
                |         This example gets interruptions of MyArrow path.
                | 
                |          oNbInterruptions = MyArrow.GetInterruptions(oInterruptions)

        :param tuple o_interruptions:
        :rtype: int
        """
        return self.drawing_arrow.GetInterruptions(o_interruptions)

    def get_point(self, i_num: int, o_x: float, o_y: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetPoint(long iNum,
                | double oX,
                | double oY)
                | 
                |     Get arrow point coordinates.
                | 
                |     Parameters:
                | 
                |         iNum
                |             Point number. 
                |         oX
                |             X coordinates of point. 
                |         oY
                |             Y coordinates of point. 
                |         Example:
                |             This example gets a point to MyArrow.
                | 
                |              iNum = 1
                |              MyArrow.GetPoint(iNum, oX, oY)

        :param int i_num:
        :param float o_x:
        :param float o_y:
        :rtype: None
        """
        return self.drawing_arrow.GetPoint(i_num, o_x, o_y)

    def get_points(self, o_points: tuple) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetPoints(CATSafeArrayVariant oPoints) As long
                | 
                |     Get arrow path.
                | 
                |     Parameters:
                | 
                |         oPoints
                |             List of points coordinates (X1,Y1,X2,Y2,.....Xn,Yn).
                |             
                | 
                |     Returns:
                |         oNbPoints Number of points. 
                |     Example:
                |         This example gets points of MyArrow path.
                | 
                |          oNbPoints = MyArrow.GetPoints(oPoints)

        :param tuple o_points:
        :rtype: int
        """
        return self.drawing_arrow.GetPoints(o_points)

    def modify_point(self, i_num: int, i_x: float, i_y: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub ModifyPoint(long iNum,
                | double iX,
                | double iY)
                | 
                |     Modify a point of an Arrow.
                | 
                |     Parameters:
                | 
                |         iNum
                |             Point number to modify. 
                |         iX
                |             X coordinates of new point. 
                |         iY
                |             Y coordinates of new point. 
                |         Example:
                |             This example modifies a point to MyArrow.
                | 
                |              iNum = 1
                |              iX = -10.
                |              iY = -20.
                |              MyArrow.ModifyPoint iNum, iX, iY

        :param int i_num:
        :param float i_x:
        :param float i_y:
        :rtype: None
        """
        return self.drawing_arrow.ModifyPoint(i_num, i_x, i_y)

    def remove_interruption(self, i_num: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub RemoveInterruption(long iNum)
                | 
                |     Remove an interruption to an arrow.
                | 
                |     Parameters:
                | 
                |         iNum
                |             Interruption number to delete. 
                |             - If iNum equals to 0, all interruptions will be removed.
                |             
                |         Example:
                |             This example removes an interruption from MyArrow.
                | 
                |              iNum = 2
                |              MyArrow.RemoveInterruption iNum

        :param int i_num:
        :rtype: None
        """
        return self.drawing_arrow.RemoveInterruption(i_num)

    def remove_point(self, i_num: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub RemovePoint(long iNum)
                | 
                |     Remove a point from an arrow.
                | 
                |     Parameters:
                | 
                |         iNum
                |             Point number to delete. 
                |         Example:
                |             This example removes a point from MyArrow.
                | 
                |              iNum = 2
                |              MyArrow.RemovePoint iNum

        :param int i_num:
        :rtype: None
        """
        return self.drawing_arrow.RemovePoint(i_num)

    def __repr__(self):
        return f'DrawingArrow(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.dnb_human_modeling_interfaces.swk_manikin import SWKManikin


class SWKBodyElement(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SWKBodyElement
                | 
                | This interface is used to access a body element (segment, ellipse,
                | ...) It provides common services for all body elements of the
                | manikin.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.swk_body_element = com_object

    @property
    def full_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FullName() As CATBSTR (Read Only)
                | 
                |     Returns the full name of the body element.
                |     This property is different from the property
                |     Name of AnyObject,
                |     which gives the short name or abbreviated name
                |     of the body element.
                | 
                |     For instance, if the body element in question is
                |     the left leg segment, then property Name
                |     yields "LSLeLe", whereas
                |     property FullName yields the character
                |     string "Left Leg".

        :rtype: str
        """

        return self.swk_body_element.FullName

    @property
    def manikin(self) -> 'SWKManikin':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Manikin() As SWKManikin (Read Only)
                | 
                |     Returns the manikin which owns this body element.

        :rtype: SWKManikin
        """
        
        from pycatia.dnb_human_modeling_interfaces.swk_manikin import SWKManikin
        return SWKManikin(self.swk_body_element.Manikin)

    @property
    def position_x(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PositionX() As double (Read Only)
                | 
                |     Returns the x coordinate of the position of the body
                |     element.
                |     If this body element is the body, then the position returned is
                |     the x-coordinate of global position of the manikin. If the
                |     body element is a segment or a line of sight, the position
                |     returned is the x-coordinate of the beginning of that segment
                |     or line of sight. If the body element is an ellipse, the
                |     x-coordinate of the center of that ellipse is returned.

        :rtype: float
        """

        return self.swk_body_element.PositionX

    @property
    def position_y(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PositionY() As double (Read Only)
                | 
                |     Returns the y coordinate of the position of the body
                |     element.
                |     If this body element is the body, then the position returned is
                |     the y-coordinate of global position of the manikin. If the
                |     body element is a segment or a line of sight, the position
                |     returned is the y-coordinate of the beginning of that segment
                |     or line of sight. If the body element is an ellipse, the
                |     y-coordinate of the center is returned.

        :rtype: float
        """

        return self.swk_body_element.PositionY

    @property
    def position_z(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PositionZ() As double (Read Only)
                | 
                |     Returns the z coordinate of the position of the body
                |     element.
                |     If this body element is the body, then the position returned is
                |     the z-coordinate of global position of the manikin. If the
                |     body element is a segment or a line of sight, the position
                |     returned is the z-coordinate of the beginning of that segment
                |     or line of sight. If the body element is an ellipse, the
                |     z-coordinate of the center is returned.

        :rtype: float
        """

        return self.swk_body_element.PositionZ

    @property
    def refresh_display(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RefreshDisplay() As boolean
                | 
                |     Enables or disables the update of the display during the
                |     script replay.
                |     To improve performance, this update can be temporarily
                |     disabled by setting this property to False in the script.
                | 
                |     The property is True if the elements display is refreshed after each
                |     posture change (value set by default).
                | 
                |     Example:
                |         This example makes the update of a manikin display disabled during a
                |         portion of the script replay.
                | 
                |          myManikin.Body.RefreshDisplay = False

        :rtype: bool
        """

        return self.swk_body_element.RefreshDisplay

    @refresh_display.setter
    def refresh_display(self, value: bool):
        """
        :param bool value:
        """

        self.swk_body_element.RefreshDisplay = value

    def get_global_position(self, po_global_position: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetGlobalPosition(CATSafeArrayVariant
                | poGlobalPosition)
                | 
                |     Returns the global position ofthe body element.
                |     If this body element is the body, then the position returned
                |     is the global position of the manikin. If the
                |     body element is a segment or a line of sight, the position
                |     returned is the global position of the beginning of that segment
                |     or line of sight. If the body element is an ellipse, the global
                |     position of the center of that ellipse is returned.

        :param tuple po_global_position:
        :rtype: None
        """
        return self.swk_body_element.GetGlobalPosition(po_global_position)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_global_position'
        # # vba_code = """
        # # Public Function get_global_position(swk_body_element)
        # #     Dim poGlobalPosition (2)
        # #     swk_body_element.GetGlobalPosition poGlobalPosition
        # #     get_global_position = poGlobalPosition
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def refresh_3d(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Refresh3D()
                | 
                |     Refreshes the 3D representation of the current element.

        :rtype: None
        """
        return self.swk_body_element.Refresh3D()

    def __repr__(self):
        return f'SWKBodyElement(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.length import Length
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeIntegratedLaw(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeIntegratedLaw
                | 
                | Represents the hybrid shape "integrated" law feature object.
                | Role: To access the data of the hybrid shape "integrated" law feature
                | object.
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapeIntegratedLaw
                | object.
                | 
                | See also:
                |     HybridShapeFactory.AddNewIntegratedLaw
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_integrated_law = com_object

    @property
    def advanced_law(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AdvancedLaw() As Reference
                | 
                |     Gets or sets the external law.
                |     Note: Used for law type = 4(Advanced)
                | 
                |     Parameters:
                | 
                |         AdvancedLaw
                |             External Law This example retrieves in ALaw the external law for
                |             the IntegratedLaw hybrid shape feature.
                | 
                |              Dim ALaw
                |              Set ALaw = IntegratedLaw.AdvancedLaw

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_integrated_law.AdvancedLaw)

    @advanced_law.setter
    def advanced_law(self, reference_law: Reference):
        """
        :param Reference reference_law:
        """

        self.hybrid_shape_integrated_law.AdvancedLaw = reference_law.com_object

    @property
    def end_param(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property EndParam() As Length (Read Only)
                | 
                |     Gets end parameter.
                |     Note: Used for law type = 2(Linear) and 3(SType).
                | 
                |     Parameters:
                | 
                |         EndParam
                |             Parameter This example retrieves in EParam the end parameter for
                |             the IntegratedLaw hybrid shape feature.
                | 
                |              Dim EParam
                |              Set EParam = IntegratedLaw.EndParam

        :rtype: Length
        """

        return Length(self.hybrid_shape_integrated_law.EndParam)

    @property
    def implicit_law_interpolation_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ImplicitLawInterpolationMode() As long
                | 
                |     Gets or sets Interpolation mode for implicit law.
                |     Note: Used for law type = 5(Implicit)
                | 
                |     Parameters:
                | 
                |         ImplicitLawInterpolationMode
                |             Implicit law interpolation mode ImplicitLawInterpolationMode =
                |             0 : CATGSMImplicitLawInterpo_None =
                |             1 : CATGSMImplicitLawInterpo_Linear =
                |             2 : CATGSMImplicitLawInterpo_Cubic This example retrieves in InterpolLawMode the
                |                 Interpolation mode for the IntegratedLaw hybrid shape feature.
                | 
                |              Dim InterpolLawMode
                |              Set InterpolLawMode = IntegratedLaw.ImplicitLawInterpolationMode

        :rtype: int
        """

        return self.hybrid_shape_integrated_law.ImplicitLawInterpolationMode

    @implicit_law_interpolation_mode.setter
    def implicit_law_interpolation_mode(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_integrated_law.ImplicitLawInterpolationMode = value

    @property
    def invert_mapping_law(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property InvertMappingLaw() As boolean
                | 
                |     Gets or sets the mapping orientation of the law.
                | 
                |     Parameters:
                | 
                |         InvertMappingLaw
                |             False : Law is applied from the beginning to the end of the curve
                |                     (mapping is not inverted).
                |             True : Law is applied from the end to the beginning of the curve (mapping is inverted).
                |                    This example retrieves in IMappingLaw the mapping orientation of the law for the
                |                    IntegratedLaw hybrid shape feature.
                | 
                |              Dim IMappingLaw
                |              Set IMappingLaw = IntegratedLaw.InvertMappingLaw

        :rtype: bool
        """

        return self.hybrid_shape_integrated_law.InvertMappingLaw

    @invert_mapping_law.setter
    def invert_mapping_law(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_integrated_law.InvertMappingLaw = value

    @property
    def pitch_law_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PitchLawType() As long
                | 
                |     Gets or sets pitch law type.
                | 
                |     Parameters:
                | 
                |         PitchLawType
                |             Type of law PitchLawType = 0 : None = 1 : Constant = 2 : Linear = 3 : SType =
                |             4 : Advanced = 5 : Implicit
                |
                |     This example retrieves in PLawType the pitch law type for the IntegratedLaw hybrid shape feature.
                | 
                |     Dim PLawType
                |     Set PLawType = IntegratedLaw.PitchLawType

        :rtype: int
        """

        return self.hybrid_shape_integrated_law.PitchLawType

    @pitch_law_type.setter
    def pitch_law_type(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_integrated_law.PitchLawType = value

    @property
    def spine(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Spine() As Reference
                | 
                |     Gets or sets Spine for implicit law.
                |     Note: Used for law type = 5 (Implicit)
                | 
                |     Parameters:
                | 
                |         Spine
                |             Spine on which implicit law inputs points are defined This example
                |             retrieves in Spine1 the spine for the IntegratedLaw hybrid shape
                |             feature.
                | 
                |              Dim Spine1
                |              Set Spine1 = IntegratedLaw.Spine

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_integrated_law.Spine)

    @spine.setter
    def spine(self, reference_spine: Reference):
        """
        :param Reference reference_spine:
        """

        self.hybrid_shape_integrated_law.Spine = reference_spine.com_object

    @property
    def start_param(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property StartParam() As Length (Read Only)
                | 
                |     Gets start parameter.
                |     Note: Used for law type = 1(Constant) ,2(Linear) and 3(SType)
                | 
                |     Parameters:
                | 
                |         StartParam
                |             Parameter This example retrieves in SParam the start parameter for
                |             the IntegratedLaw hybrid shape feature.
                | 
                |              Dim SParam
                |              Set SParam = IntegratedLaw.StartParam

        :rtype: Length
        """

        return Length(self.hybrid_shape_integrated_law.StartParam)

    def append_new_point_and_param(self, i_point: Reference, i_param: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AppendNewPointAndParam(Reference iPoint,
                | long iParam)
                | 
                |     Sets 'Point on spine' and associated parameter.
                |     Note: Used for law type = 5(Implicit)
                | 
                |     Parameters:
                | 
                |         iPoint
                |             Point on spine 
                |         iParam
                |             Corresponding parameter

        :param Reference i_point:
        :param int i_param:
        :rtype: None
        """
        return self.hybrid_shape_integrated_law.AppendNewPointAndParam(i_point.com_object, i_param)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'append_new_point_and_param'
        # # vba_code = """
        # # Public Function append_new_point_and_param(hybrid_shape_integrated_law)
        # #     Dim iPoint (2)
        # #     hybrid_shape_integrated_law.AppendNewPointAndParam iPoint
        # #     append_new_point_and_param = iPoint
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_point_and_param(self, i_pos: int, o_point: Reference, o_param: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetPointAndParam(long iPos,
                | Reference oPoint,
                | Reference oParam)
                | 
                |     Gets the point on spine and associated parameter at a given
                |     position.
                |     Note: Used for law type = 5(Implicit)
                | 
                |     Parameters:
                | 
                |         iPos
                |             given position 
                |         oPoint
                |             point on spine 
                |         oParam
                |             corresponding parameter

        :param int i_pos:
        :param Reference o_point:
        :param Reference o_param:
        :rtype: None
        """
        return self.hybrid_shape_integrated_law.GetPointAndParam(i_pos, o_point.com_object, o_param.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_point_and_param'
        # # vba_code = """
        # # Public Function get_point_and_param(hybrid_shape_integrated_law)
        # #     Dim iPos (2)
        # #     hybrid_shape_integrated_law.GetPointAndParam iPos
        # #     get_point_and_param = iPos
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_size(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetSize() As long
                | 
                |     Gets the size of the list in the law i.e. number of points in the list of
                |     the law.
                | 
                |     Parameters:
                | 
                |         oSize
                |             size of the list.

        :rtype: int
        """
        return self.hybrid_shape_integrated_law.GetSize()

    def remove_all_points_and_params(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveAllPointsAndParams()
                | 
                |     Removes all the points and associated parameters.
                |     Note: Used for law type = 5(Implicit)

        :rtype: None
        """
        return self.hybrid_shape_integrated_law.RemoveAllPointsAndParams()

    def remove_point_and_param(self, i_point: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemovePointAndParam(Reference iPoint)
                | 
                |     Removes a point and its parameter. for law type = 5(Implicit)
                | 
                |     Parameters:
                | 
                |         iSpecPoint
                |             Point to remove

        :param Reference i_point:
        :rtype: None
        """
        return self.hybrid_shape_integrated_law.RemovePointAndParam(i_point.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_point_and_param'
        # # vba_code = """
        # # Public Function remove_point_and_param(hybrid_shape_integrated_law)
        # #     Dim iPoint (2)
        # #     hybrid_shape_integrated_law.RemovePointAndParam iPoint
        # #     remove_point_and_param = iPoint
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_end_param(self, i_end_param: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetEndParam(long iEndParam)
                | 
                |     Sets end parameter.
                |     Note: Used for law type = 2(Linear) and 3(SType).
                | 
                |     Parameters:
                | 
                |         iEndParam
                |             Parameter

        :param int i_end_param:
        :rtype: None
        """
        return self.hybrid_shape_integrated_law.SetEndParam(i_end_param)

    def set_start_param(self, i_start_param: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetStartParam(long iStartParam)
                | 
                |     Sets start parameter.
                |     Note: Used for law type = 1(Constant) ,2(Linear) and 3(SType).
                | 
                |     Parameters:
                | 
                |         iStartParam
                |             Parameter

        :param int i_start_param:
        :rtype: None
        """
        return self.hybrid_shape_integrated_law.SetStartParam(i_start_param)

    def __repr__(self):
        return f'HybridShapeIntegratedLaw(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.parameter import Parameter
from pycatia.sketcher_interfaces.sketch import Sketch
from pycatia.structure_interfaces.str_object import StrObject


class StrPlate(StrObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ProductStructureInterfaces.Product
                |                         StructureInterfaces.StrObject
                |                             StrPlate
                | 
                | Represents a structure plate object.
                | A plate is defined by a thickness and aggregates a support object and a sketch
                | defining its contour.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.str_plate = com_object

    @property
    def offset(self) -> Parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Offset() As Parameter (Read Only)
                | 
                |     Returns the offset between the given support and the support of the plate.

        :rtype: Parameter
        """

        return Parameter(self.str_plate.Offset)

    @property
    def sketch(self) -> Sketch:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Sketch() As Sketch (Read Only)
                | 
                |     Returns the sketch object of the plate.

        :rtype: Sketch
        """

        return Sketch(self.str_plate.Sketch)

    @property
    def standard_thickness(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StandardThickness() As double
                | 
                |     Returns the standard thickness following the support orientation.

        :rtype: float
        """

        return self.str_plate.StandardThickness

    @standard_thickness.setter
    def standard_thickness(self, value: float):
        """
        :param float value:
        """

        self.str_plate.StandardThickness = value

    @property
    def support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Support() As Reference
                | 
                |     Returns or sets the support of the plate.

        :rtype: Reference
        """

        return Reference(self.str_plate.Support)

    @support.setter
    def support(self, value: Reference):
        """
        :param Reference value:
        """

        self.str_plate.Support = value.com_object

    def reverse_direction(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ReverseDirection()
                | 
                |     Reverses the material orientation of the plate.
                | 
                |      Plate_1.ReverseDirection

        :rtype: None
        """
        return self.str_plate.ReverseDirection()

    def set_material_and_grade(self, i_material: str, i_grade: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMaterialAndGrade(CATBSTR iMaterial,
                | CATBSTR iGrade)

        :param str i_material:
        :param str i_grade:
        :rtype: None
        """
        return self.str_plate.SetMaterialAndGrade(i_material, i_grade)

    def __repr__(self):
        return f'StrPlate(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class TPSParallelOnScreen(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     TPSParallelOnScreen
                | 
                | Interface for Parallel On Screen.
                | TPS for Technological Product Specifications.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.tps_parallel_on_screen = com_object

    @property
    def parallel_on_screen(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ParallelOnScreen() As boolean
                | 
                |     Retrieves the Parallel On Screen for the annotation.

        :rtype: bool
        """

        return self.tps_parallel_on_screen.ParallelOnScreen

    @parallel_on_screen.setter
    def parallel_on_screen(self, value: bool):
        """
        :param bool value:
        """

        self.tps_parallel_on_screen.ParallelOnScreen = value

    @property
    def zoomable(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Zoomable() As boolean
                | 
                |     Retrieves the Zoomable for the annotation.

        :rtype: bool
        """

        return self.tps_parallel_on_screen.Zoomable

    @zoomable.setter
    def zoomable(self, value: bool):
        """
        :param bool value:
        """

        self.tps_parallel_on_screen.Zoomable = value

    def __repr__(self):
        return f'TpsParallelOnScreen(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.mec_mod_interfaces.ordered_geometrical_set import OrderedGeometricalSet
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class OrderedGeometricalSets(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     OrderedGeometricalSets
                | 
                | A collection of the OrderedGeometricalSet objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=OrderedGeometricalSet)
        self.ordered_geometrical_sets = com_object

    def add(self) -> OrderedGeometricalSet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Add() As OrderedGeometricalSet
                | 
                |     Creates a new ordered geometrical set and adds it to the
                |     OrderedGeometricalSets collection. Thisordered geometrical set becomes the
                |     current one
                | 
                |     Returns:
                |         The created ordered geometrical set 
                |     Example:
                |         The following example creates a ordered geometrical set named
                |         newOrderedGeometricalSet in the ordered geometrical set collection of the
                |         rootPart part in the partDoc part document. NewPartBody becomes the in work
                |         object of partDoc.
                | 
                |          Set NewPartBody = rootPart.OrderedGeometricalSets.Add()

        :rtype: OrderedGeometricalSet
        """
        return OrderedGeometricalSet(self.ordered_geometrical_sets.Add())

    def item(self, i_index: cat_variant) -> OrderedGeometricalSet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Item(CATVariant iIndex) As OrderedGeometricalSet
                | 
                |     Returns a ordered geometrical set using its index or its name from the
                |     ordered geometrical set collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the ordered geometrical set to retrieve
                |             from the collection of ordered geometrical sets. As a numerics, this index is
                |             the rank of the ordered geometrical set in the collection. The index of the
                |             first ordered geometrical set in the collection is 1, and the index of the last
                |             ordered geometrical set is Count. As a string, it is the name you assigned to
                |             the ordered geometrical set using the 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved ordered geometrical set 
                |     Example:
                |         This example retrieves in ThisOrderedGeometricalSet the fifth ordered
                |         geometrical set in the collection and in ThatOrderedGeometricalSet the ordered
                |         geometrical set named MyOrderedGeometricalSet in the ordered geometrical set
                |         collection of the partDoc part document.
                | 
                |          Set orderedGeometricalSetColl = partDoc.Part.OrderedGeometricalSets
                |          Set ThisOrderedGeometricalSet = orderedGeometricalSetColl.Item(5)
                |          Set ThatOrderedGeometricalSet = orderedGeometricalSetColl.Item("MyOrderedGeometricalSet")

        :param cat_variant i_index:
        :rtype: OrderedGeometricalSet
        """
        return OrderedGeometricalSet(self.ordered_geometrical_sets.Item(i_index))

    def __getitem__(self, n: int) -> OrderedGeometricalSet:
        if (n + 1) > self.count:
            raise StopIteration

        return OrderedGeometricalSet(self.ordered_geometrical_sets.Item(n + 1))

    def __iter__(self) -> Iterator[OrderedGeometricalSet]:
        for i in range(self.count):
            yield self.child_object(self.com_object.Item(i + 1))

    def __repr__(self):
        return f'OrderedGeometricalSets(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.eno_cd5_interfaces.cd5_id import CD5ID
from pycatia.system_interfaces.any_object import AnyObject


class CD5SaveItem(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CD5SaveItem
                | 
                | Represents a save object which user is trying to save.
                | 
                | Various properties on the object help the end-user to customize each object
                | individually.
                | 
                | Example:
                | 
                |       The following example indicates how to retrieve an item in the scope of a
                |       Save Operation.
                |
                |      Dim oCD5Engine As CD5EngineV6R2014x
                |      Set oCD5Engine = CATIA.GetItem("CD5EngineV6R2014x")
                |      Dim oSaveOperation As CD5SaveOperation
                |      Set oSaveOperation = oCD5Engine.CreateSaveOperation(CD5SaveOperation_Session)
                |      Dim oSaveItems As CD5SaveItems
                |      Set oSaveItems = oSaveOperation.Items()
                |      Dim oSaveItem As CD5SaveItem
                |      Set oSaveItem = oSaveItems.Item(1)
                |
                | See also:
                |     CD5SaveItems
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.cd5_save_item = com_object

    @property
    def cd5_id(self) -> CD5ID:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CD5ID() As CD5ID (Read Only)
                | 
                |     Returns (gets) the CD5ID for a save item.
                | 
                |     Example:
                | 
                |           The following example gets CD5ID from a save item.
                |
                |          Dim myID As CD5ID
                |          Set myID = oSaveItem.CD5ID

        :rtype: CD5ID
        """

        return CD5ID(self.cd5_save_item.CD5ID)

    @property
    def derived_outputs(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DerivedOutputs(CATSafeArrayVariant
                | DerivedOutputs)
                | 
                |     Returns (gets) or sets the Derived Outputs for a save
                |     item.
                | 
                |     Example:
                | 
                |           The following example sets Derived Outputs from a save
                |           item.
                |
                |          Dim iDerivedOutputs(1) As CATBSTR
                |          iDerivedOutputs(0) = "cgrOutput"
                |          oSaveItem.DerivedOutputs = iDerivedOutputs

        :rtype: tuple
        """

        return self.cd5_save_item.DerivedOutputs

    @derived_outputs.setter
    def derived_outputs(self, value: tuple):
        """
        :param tuple value:
        """

        self.cd5_save_item.DerivedOutputs = value

    @property
    def included(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Included() As boolean
                | 
                |     Returns (gets) or sets whether item should be included in the Save
                |     Operation. The default value is determined by the status of the item. Objects
                |     with status "Exists" are not selected by default.
                | 
                |     Example:
                | 
                |           The following example includes the item for the Save
                |           operation.
                |
                |          oSaveItem.Included = True

        :rtype: bool
        """

        return self.cd5_save_item.Included

    @included.setter
    def included(self, value: bool):
        """
        :param bool value:
        """

        self.cd5_save_item.Included = value

    @property
    def next_revision(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NextRevision() As CATBSTR (Read Only)
                | 
                |     Returns the next combined revision and version string for this
                |     CD5SaveItem.
                |     If next revision of the item is to be created, then CD5SaveItem.Revision
                |     may be set to this value.
                | 
                |     Example:
                | 
                |           The following example gets the NextRevision of the
                |           item.
                |
                |          CD5SaveItem.Revision = CD5SaveItem.NextRevision

        :rtype: str
        """

        return self.cd5_save_item.NextRevision

    @property
    def object_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ObjectName() As CATBSTR
                | 
                |     Returns (gets) or sets the value of the ENOVIA Object
                |     Name.
                | 
                |     Example:
                | 
                |           The following example sets the Object Name.
                |
                |          oSaveItem.ObjectName = "MyPart"

        :rtype: str
        """

        return self.cd5_save_item.ObjectName

    @object_name.setter
    def object_name(self, value: str):
        """
        :param str value:
        """

        self.cd5_save_item.ObjectName = value

    @property
    def possible_derived_outputs(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PossibleDerivedOutputs() As CATSafeArrayVariant (Read
                | Only)
                | 
                |     Returns (gets) the possible Derived Outputs for a save
                |     item.
                | 
                |     Example:
                | 
                |           The following example gets Possible DerivedOutputs from a save
                |           item.
                |
                |          Dim oPossibleDerivedOutputs As CATSafeArrayVariant
                |          oPossibleDerivedOutputs = oSaveItem.PossibleDerivedOutputs

        :rtype: tuple
        """

        return self.cd5_save_item.PossibleDerivedOutputs

    @property
    def possible_types(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PossibleTypes() As CATSafeArrayVariant (Read Only)
                | 
                |     Returns (gets) the possible Types for a save item.
                | 
                |     Example:
                | 
                |           The following example gets PossibleTypes from a save
                |           item.
                |
                |          Dim oPossibleTypes As CATSafeArrayVariant
                |          oPossibleTypes = oSaveItem.PossibleTypes

        :rtype: tuple
        """

        return self.cd5_save_item.PossibleTypes

    @property
    def revision(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Revision() As CATBSTR
                | 
                |     Returns or sets the target revision of the CD5SaveItem for the Save
                |     Operation. Default value is current CD5SaveItem target
                |     revision.
                |     Get: will return string combining revision and version (ex:
                |     "B.3").
                |     Set: will keep the revision string only (e.g. "A", "BB"), even if combining
                |     revision and version is passed.
                | 
                |     Note:
                |         As revision part of the string cannot contain ‘.’ character, given
                |         string may be truncated up to the first ‘.’ character’ before being appended
                |         with appropriate version number.
                |         (ex: MyItem.Revision = "AA.BB" => property is set to "AA.0")
                |         It is advised to read the Revision property after it has been set as
                |         the current value may not match what has been set. 
                |         Changing the CD5SaveOperation.CreateVersion value may affect the
                |         version part of this property.
                | 
                |         Example:
                | 
                |               The following example gets the targeted Revision for the
                |               item.
                |
                |              Dim oRevision As CATBSTR
                |              oRevision = CD5SaveItem.Revision

        :rtype: str
        """

        return self.cd5_save_item.Revision

    @revision.setter
    def revision(self, value: str):
        """
        :param str value:
        """

        self.cd5_save_item.Revision = value

    @property
    def status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Status() As CD5SaveItem_Status (Read Only)
                | 
                |     Returns (gets) the Save status of the item.
                | 
                |     Example:
                | 
                |           The following example gets item Status.
                |
                |          Dim itemStatus As CD5SaveItem_Status
                |          itemStatus = oSaveItem.Status

        :return: enum cd5_save_item_status
        :rtype: int
        """

        return self.cd5_save_item.Status

    @property
    def type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As CATBSTR
                | 
                |     Returns (gets) or sets the Type of the item. The default value is picked
                |     from the GCO. To set a type user can get the list of Possible Types from
                |     PossibleTypes property
                | 
                |     Example:
                | 
                |           The following example gets the type of the item.
                |
                |          Dim oType As CATBSTR
                |          oType = oSaveItem.Type

        :rtype: str
        """

        return self.cd5_save_item.Type

    @type.setter
    def type(self, value: str):
        """
        :param str value:
        """

        self.cd5_save_item.Type = value

    def __repr__(self):
        return f'CD5SaveItem(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.types.general import cat_variant
from pycatia.drafting_interfaces.drawing_view import DrawingView
from pycatia.system_interfaces.collection import Collection


class DrawingViews(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     DrawingViews
                | 
                | A collection of all the drawing views currently managed by a drawing sheet in a
                | drawing document.
                | 
                | Warning: This interface is not available with 2D Layout for 3D
                | Design.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=DrawingView)
        self.drawing_views = com_object

    @property
    def active_view(self) -> DrawingView:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ActiveView() As DrawingView (Read Only)
                | 
                |     Returns the active drawing view of the active drawing
                |     sheet.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Example:
                |         The following example retrieves in ViewToWorkIn the active drawing view
                |         in the DrawingSheets collection of the document named
                |         CATDrawing1
                | 
                |          Dim MyDrawingDoc As Document
                |          Set MyDrawingDoc = CATIA.Documents.Item("CATDrawing1")
                |          Dim ViewToWorkIn As DrawingView
                |          Set ViewToWorkIn = MyDrawingDoc.Sheets.ActiveSheet.DrawingViews.ActiveView

        :rtype: DrawingView
        """

        return DrawingView(self.drawing_views.ActiveView)

    def add(self, i_drawing_view_name: str) -> DrawingView:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Add(CATBSTR iDrawingViewName) As DrawingView
                | 
                |     Creates a drawing view and adds it to the drawing view collection. This
                |     drawing view becomes the active one.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Parameters:
                | 
                |         iDrawingViewName
                |             The name to assign to the created drawing view 
                | 
                |     Returns:
                |         The created drawing view 
                | 
                | Example:
                |     The following example creates a drawing view named LeftView and retrieved
                |     in MyView in the drawing view collection of the MySheet drawing sheet. This
                |     sheet belongs to the drawing sheet collection of the drawing document named
                |     CATDrawing1.
                | 
                |      Dim MyDrawingDoc As Document
                |      Set MyDrawingDoc = CATIA.Documents.Item("CATDrawing1")
                |      Dim MySheet As DrawingSheet
                |      Set MySheet = MyDrawingDoc.Sheets.Item("FirstSheet")
                |      Dim MyView As DrawingView
                |      Set MyView = MySheet.Views.Add("LeftView")

        :param str i_drawing_view_name:
        :rtype: DrawingView
        """
        return DrawingView(self.drawing_views.Add(i_drawing_view_name))

    def item(self, i_index: cat_variant) -> DrawingView:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(CATVariant iIndex) As DrawingView
                | 
                |     Returns a drawing view using its index or its name from the DrawingViews
                |     collection.
                |     Warning: This method is not available with 2D Layout for 3D
                |     Design.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the drawing view to retrieve from the
                |             collection of drawing views. As a numerics, this index is the rank of the
                |             drawing view in the collection. The index of the first drawing view in the
                |             collection is 1, and the index of the last drawing view is Count. As a string,
                |             it is the name you assigned to the drawing view using the
                |             
                | 
                |         AnyObject.Name property or when creating it using the Add method.
                |         
                |     Returns:
                |         The retrieved drawing view 
                |     Example:
                | 
                |           This example retrieves in ThisDrawingView the second drawing
                |           view,
                |          and in ThatDrawingView the drawing view named
                |          MyView in the drawing view collection of the active
                |          sheet
                |          in the active document, supposed to be a drawing
                |          document.
                |          
                | 
                |          Dim MySheet As DrawingSheet
                |          Set MySheet = CATIA.ActiveDocument.Sheets.ActiveSheet
                |          Dim ThisDrawingView As DrawingView
                |          Set ThisDrawingView = MySheet.Views.ActiveView.Item(2)
                |          Dim ThatDrawingView As DrawingView
                |          Set ThatDrawingView = MySheet.Views.ActiveView.Item("MyView")

        :param cat_variant i_index:
        :rtype: DrawingView
        """
        return DrawingView(self.drawing_views.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a drawing view from the DrawingViews collection.
                |     Warning: This method is not available with 2D Layout for 3D Design and it's
                |     forbidden and not possible to delete main view and background view contained in
                |     this collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the drawing view to remove from the
                |             collection of drawing views. As a numerics, this index is the rank of the
                |             drawing view in the collection. The index of the first drawing view in the
                |             collection is 1, and the index of the last drawing view is Count. As a string,
                |             it is the name you assigned to the drawing view using the
                |             
                | 
                |         AnyObject.Name property or when creating it using the Add method.
                |         
                | 
                | Example:
                |     The following example removes the third drawing view and the drawing view
                |     named TopView in the drawing view collection of the active sheet of the active
                |     document, supposed to be a drawing document.
                | 
                |      Dim MySheet As DrawingSheet
                |      Set MySheet = CATIA.ActiveDocument.Sheets.ActiveSheet
                |      MySheet.ActiveViews.Remove(3)
                |      MySheet.ActiveViews.Remove("TopView")

        :param cat_variant i_index:
        :rtype: None
        """
        return self.drawing_views.Remove(i_index)

    def __getitem__(self, n: int) -> DrawingView:
        if (n + 1) > self.count:
            raise StopIteration

        return DrawingView(self.drawing_views.Item(n + 1))

    def __iter__(self) -> Iterator[DrawingView]:
        for i in range(self.count):
            yield self.child_object(self.com_object.Item(i + 1))

    def __repr__(self):
        return f'DrawingViews(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.product_structure_interfaces.product import Product
from pycatia.smt_interfaces.free_space import FreeSpace
from pycatia.system_interfaces.collection import Collection


class FreeSpaces(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     FreeSpaces
                | 
                | Interface to compute Free Spaces.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=FreeSpace)
        self.free_spaces = com_object

    def add(
            self,
            i_product_for_free_space: Product,
            i_accuracy: float,
            i_xmin: float,
            i_xmax: float,
            i_ymin: float,
            i_ymax: float,
            i_zmin: float,
            i_zmax: float,
            i_type_free_space: int,
            i_xpt: float,
            i_ypt: float,
            i_zpt: float,
            i_holes: tuple,
            i_shape_name: str,
            i_activated_shape: int,
            i_default_shape: int
    ) -> FreeSpace:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(Product iProductForFreeSpace,
                | double iAccuracy,
                | double iXmin,
                | double iXmax,
                | double iYmin,
                | double iYmax,
                | double iZmin,
                | double iZmax,
                | long iTypeFreeSpace,
                | double iXpt,
                | double iYpt,
                | double iZpt,
                | CATSafeArrayVariant iHoles,
                | CATBSTR iShapeName,
                | long iActivatedShape,
                | long iDefaultShape) As FreeSpace
                | 
                |     Compute a free space around a selected product.

        :param Product i_product_for_free_space:
        :param float i_accuracy:
        :param float i_xmin:
        :param float i_xmax:
        :param float i_ymin:
        :param float i_ymax:
        :param float i_zmin:
        :param float i_zmax:
        :param int i_type_free_space:
        :param float i_xpt:
        :param float i_ypt:
        :param float i_zpt:
        :param tuple i_holes:
        :param str i_shape_name:
        :param int i_activated_shape:
        :param int i_default_shape:
        :rtype: FreeSpace
        """
        return FreeSpace(
            self.free_spaces.Add(
                i_product_for_free_space.com_object,
                i_accuracy,
                i_xmin,
                i_xmax,
                i_ymin,
                i_ymax,
                i_zmin,
                i_zmax,
                i_type_free_space,
                i_xpt,
                i_ypt,
                i_zpt,
                i_holes,
                i_shape_name,
                i_activated_shape,
                i_default_shape
            )
        )

    def add_around_any(
            self,
            i_accuracy: float,
            i_xmin: float,
            i_xmax: float,
            i_ymin: float,
            i_ymax: float,
            i_zmin: float,
            i_zmax: float,
            i_shape_name: str,
            i_type_free_space: int,
            i_holes: tuple
    ) -> FreeSpace:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddAroundAny(double iAccuracy,
                | double iXmin,
                | double iXmax,
                | double iYmin,
                | double iYmax,
                | double iZmin,
                | double iZmax,
                | CATBSTR iShapeName,
                | long iTypeFreeSpace,
                | CATSafeArrayVariant iHoles) As FreeSpace
                | 
                |     Compute a free space around any products.

        :param float i_accuracy:
        :param float i_xmin:
        :param float i_xmax:
        :param float i_ymin:
        :param float i_ymax:
        :param float i_zmin:
        :param float i_zmax:
        :param str i_shape_name:
        :param int i_type_free_space:
        :param tuple i_holes:
        :rtype: FreeSpace
        """
        return FreeSpace(
            self.free_spaces.AddAroundAny(
                i_accuracy,
                i_xmin,
                i_xmax,
                i_ymin,
                i_ymax,
                i_zmin,
                i_zmax,
                i_shape_name,
                i_type_free_space,
                i_holes
            )
        )

    def add_around_products(
            self,
            i_accuracy: float,
            i_xmin: float,
            i_xmax: float,
            i_ymin: float,
            i_ymax: float,
            i_zmin: float,
            i_zmax: float,
            i_shape_name: str,
            i_type_free_space: int,
            i_holes: tuple,
            i_reference_selection: tuple
    ) -> FreeSpace:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddAroundProducts(double iAccuracy,
                | double iXmin,
                | double iXmax,
                | double iYmin,
                | double iYmax,
                | double iZmin,
                | double iZmax,
                | CATBSTR iShapeName,
                | long iTypeFreeSpace,
                | CATSafeArrayVariant iHoles,
                | CATSafeArrayVariant iReferenceSelection) As FreeSpace
                | 
                |     Compute a free space around a reference selection

        :param float i_accuracy:
        :param float i_xmin:
        :param float i_xmax:
        :param float i_ymin:
        :param float i_ymax:
        :param float i_zmin:
        :param float i_zmax:
        :param str i_shape_name:
        :param int i_type_free_space:
        :param tuple i_holes:
        :param tuple i_reference_selection:
        :rtype: FreeSpace
        """
        return FreeSpace(
            self.free_spaces.AddAroundProducts(
                i_accuracy,
                i_xmin,
                i_xmax,
                i_ymin,
                i_ymax,
                i_zmin,
                i_zmax,
                i_shape_name,
                i_type_free_space,
                i_holes,
                i_reference_selection
            )
        )

    def add_from_file(self, i_file_name: str, i_shape_name: str) -> FreeSpace:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddFromFile(CATBSTR iFileName,
                | CATBSTR iShapeName) As FreeSpace
                | 
                |     Compute a free space from a file.

        :param str i_file_name:
        :param str i_shape_name:
        :rtype: FreeSpace
        """
        return FreeSpace(self.free_spaces.AddFromFile(i_file_name, i_shape_name))

    def add_inflating_from_file(self, i_file_name: str, i_shape_name: str) -> FreeSpace:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddInflatingFromFile(CATBSTR iFileName,
                | CATBSTR iShapeName) As FreeSpace
                | 
                |     Compute an inflating free space from a file.

        :param str i_file_name:
        :param str i_shape_name:
        :rtype: FreeSpace
        """
        return FreeSpace(self.free_spaces.AddInflatingFromFile(i_file_name, i_shape_name))

    def add_split_from_file(
            self,
            i_x: float,
            i_y: float,
            i_z: float,
            i_nx: float,
            i_ny: float,
            i_nz: float,
            i_file_name: str,
            i_shape_name: str
    ) -> FreeSpace:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddSplitFromFile(double iX,
                | double iY,
                | double iZ,
                | double iNx,
                | double iNy,
                | double iNz,
                | CATBSTR iFileName,
                | CATBSTR iShapeName) As FreeSpace
                | 
                |     Compute a split free space from a file.

        :param float i_x:
        :param float i_y:
        :param float i_z:
        :param float i_nx:
        :param float i_ny:
        :param float i_nz:
        :param str i_file_name:
        :param str i_shape_name:
        :rtype: FreeSpace
        """
        return FreeSpace(self.free_spaces.AddSplitFromFile(i_x, i_y, i_z, i_nx, i_ny, i_nz, i_file_name, i_shape_name))

    def __repr__(self):
        return f'FreeSpaces(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_fastener_interfaces.fastener import Fastener
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.system_interfaces.cat_base_dispatch import CATBaseDispatch


class PointFastener(Fastener):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DNBFastenerInterfaces.Fastener
                |                         PointFastener
                | 
                | Interface DELMIAPointFastener DELMIAPointFastener represent body in white
                | fasteners of type point.
                | Following kind of point fasteners are by default available with DPM - Fastening
                | Process Planner Sealant Point, Spot Weld, Stud, Glue Drop, Rivet, Screw,
                | Clinch, Drill, Adhesive Point
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.point_fastener = com_object

    def get_design_xyzypr(self, io_xyzypr: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetDesignXYZYPR(CATSafeArrayVariant ioXYZYPR)
                | 
                |     Returns Design data of the fastener. YPR values are in Degree.
                |     
                | 
                | Example:
                |     Dim DesignPos() ReDim DesignPos(5) MyFastener.GetDesignXYZYPR(DesignPos)

        :param tuple io_xyzypr:
        :rtype: None
        """
        return self.point_fastener.GetDesignXYZYPR(io_xyzypr)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_design_xyzypr'
        # # vba_code = """
        # # Public Function get_design_xyzypr(point_fastener)
        # #     Dim ioXYZYPR (2)
        # #     point_fastener.GetDesignXYZYPR ioXYZYPR
        # #     get_design_xyzypr = ioXYZYPR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_tag(self) -> CATBaseDispatch:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTag() As CATBaseDispatch
                | 
                |     Returns a DELMIATag object from fastener 
                | 
                | Example:
                |     MyTag = MyFastener.GetTag()

        :rtype: AnyObject
        """
        return self.point_fastener.GetTag()

    def reset_position(self, i_val: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetPosition(boolean iVal)
                | 
                |     Sets the position of point fastener to design position or DPE Saved Manufacturing Position Valid Param : 0,1 
                | 
                | Example:
                |     //to reset the position to design position MyFastener.ResetPosition(0) //to
                |     reset the position to DPE Saved Manufacturing Position
                |     MyFastener.ResetPosition(1)
                | 
                |     Copyright © 1999-2011, Dassault Systèmes. All rights
                |     reserved.

        :param bool i_val:
        :rtype: None
        """
        return self.point_fastener.ResetPosition(i_val)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'reset_position'
        # # vba_code = """
        # # Public Function reset_position(point_fastener)
        # #     Dim iVal (2)
        # #     point_fastener.ResetPosition iVal
        # #     reset_position = iVal
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'PointFastener(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.parameter import Parameter
from pycatia.structure_interfaces.str_cutback import StrCutback
from pycatia.structure_interfaces.str_member_extremity import StrMemberExtremity
from pycatia.structure_interfaces.str_object import StrObject
from pycatia.structure_interfaces.str_section import StrSection


class StrMember(StrObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ProductStructureInterfaces.Product
                |                         StructureInterfaces.StrObject
                |                             StrMember
                | 
                | Represents a member object.
                | The member object aggregates a section coming from a catalog, a support and two
                | extremities. The member object inherits all methods from the structure object
                | and the product object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.str_member = com_object

    @property
    def angle(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Angle() As double
                | 
                |     Returns or set the orientation of the section on the support
                |     object.
                | 
                |     Example:
                | 
                |           
                | 
                |          angle = Member_1.Angle

        :rtype: float
        """

        return self.str_member.Angle

    @angle.setter
    def angle(self, value: float):
        """
        :param float value:
        """

        self.str_member.Angle = value

    @property
    def angle_parameter(self) -> Parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AngleParameter() As Parameter (Read Only)
                | 
                |     Returns the parameter used to define the orientation of the section on the
                |     support object.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim angle As Parameter
                |          Set angle = Member_1.AngleParameter

        :rtype: Parameter
        """

        return Parameter(self.str_member.AngleParameter)

    @property
    def current_anchor_point_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CurrentAnchorPointName() As CATBSTR
                | 
                |     Returns or sets the current anchor point used to locate the section on the
                |     support object.
                | 
                |     Example:
                | 
                |           
                | 
                |          name = Member_1.CurrentAnchorPointName

        :rtype: str
        """

        return self.str_member.CurrentAnchorPointName

    @current_anchor_point_name.setter
    def current_anchor_point_name(self, value: str):
        """
        :param str value:
        """

        self.str_member.CurrentAnchorPointName = value

    @property
    def end_extremity(self) -> StrMemberExtremity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EndExtremity() As StrMemberExtremity (Read Only)
                | 
                |     Returns the member's end extremity object.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim extremity As StrMemberExtremity
                |          Set extremity = Member_1.EndExtremity

        :rtype: StrMemberExtremity
        """

        return StrMemberExtremity(self.str_member.EndExtremity)

    @property
    def input_support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property InputSupport() As Reference (Read Only)
                | 
                |     Retrieves the input support. The input support is the given support at the
                |     creation of the member.

        :rtype: Reference
        """

        return Reference(self.str_member.InputSupport)

    @property
    def section(self) -> StrSection:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Section() As StrSection (Read Only)
                | 
                |     Returns or sets the section object.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim section As StrSection
                |          Set section = Member_1.Section

        :rtype: StrSection
        """

        return StrSection(self.str_member.Section)

    @property
    def start_extremity(self) -> StrMemberExtremity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StartExtremity() As StrMemberExtremity (Read Only)
                | 
                |     Returns the member's start extremity object.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim extremity As StrMemberExtremity
                |          Set extremity = Member_1.StartExtremity

        :rtype: StrMemberExtremity
        """

        return StrMemberExtremity(self.str_member.StartExtremity)

    @property
    def support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Support() As Reference (Read Only)
                | 
                |     Retrieves the result support object. For example, if your member object is
                |     created using two points, the result support object will be the line joining
                |     these two points.

        :rtype: Reference
        """

        return Reference(self.str_member.Support)

    @property
    def surface_reference(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SurfaceReference() As Reference
                | 
                |     Retrieves or sets the surface reference object for the member. The section
                |     will be oriented using this surface reference object if one is set.
                |     Nevertheless, the surface reference object can be null.
                | 
                |     Example:
                |         This example sets the reference object to null.
                | 
                |          myMember.SurfaceReference = Nothing

        :rtype: Reference
        """

        return Reference(self.str_member.SurfaceReference)

    @surface_reference.setter
    def surface_reference(self, value: Reference):
        """
        :param Reference value:
        """

        self.str_member.SurfaceReference = value.com_object

    def create_cutback(self, i_member: 'StrMember', i_cutback: int, i_offset: float) -> StrCutback:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateCutback(StrMember iMember,
                | CatStrCutbackType iCutback,
                | double iOffset) As StrCutback
                | 
                |     Creates a cutback object between two member objects.
                | 
                |     Parameters:
                | 
                |         iMember
                |             The relimiting member 
                |         iCutback
                |             The type of the cutback. 
                |         iOffset
                |             The offset used in the cutback. 
                | 
                |     Example:
                | 
                |           The following example create a cutback 
                |          
                |          
                | 
                |          Dim cutback As StrCutback
                |          Set cutback = Member_1.CreateCutback(Member_2, catStrWeldedType, 0.05)

        :param StrMember i_member:
        :param int i_cutback: enum cat_str_cutback_type
        :param float i_offset:
        :rtype: StrCutback
        """
        return StrCutback(self.str_member.CreateCutback(i_member.com_object, i_cutback, i_offset))

    def flip(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Flip()
                | 
                |     Flips the section. Useful for asymetric section as the angle section, or
                |     the channel section.
                | 
                |     Example:
                | 
                |           
                | 
                |          Member_1.Rotate(1,25)

        :rtype: None
        """
        return self.str_member.Flip()

    def rotate(self, i_angle: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Rotate(double iAngle)
                | 
                |     Rotates the section on its support object. The given angle is applied using
                |     the current orientation of the section.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim extremity As StrMemberExtremity
                |          Set extremity = Member_1.StartExtremity

        :param float i_angle:
        :rtype: None
        """
        return self.str_member.Rotate(i_angle)

    def __repr__(self):
        return f'StrMember(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_plant_ship_interfaces.psp_group import PSPGroup
from pycatia.cat_plant_ship_interfaces.psp_list_of_objects import PSPListOfObjects
from pycatia.cat_plant_ship_interfaces.psp_logical_line import PSPLogicalLine
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class PSPAppFactory(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspAppFactory
                | 
                | Represents the application factory.
                | Role: To create, instanciate, delete and query groups, logical lines,
                | compartments and parts.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_app_factory = com_object

    def create_group(self, i_current_product: Product, i_group_type: str, i_group_id: str) -> PSPGroup:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateGroup(Product iCurrentProduct,
                | CATBSTR iGroupType,
                | CATBSTR iGroupID) As PspGroup
                | 
                |     Creates a group in the current Product.
                | 
                |     Parameters:
                | 
                |         iCurrentProduct
                |             The current Product to query. 
                |         iGroupType
                |             Group Startup type. 
                |         iGroupID
                |             Group ID. A default ID will be generated if input is NULL.
                |
                |     Returns:
                |         Created Group instance. 
                |     Example:
                |
                |          Dim objThisIntf As PspAppFactory
                |          Dim iobj1 As Product
                |          Dim iStrVar2 As String
                |          Dim iStrVar3 As String
                |          Dim iObj4 As PspGroup
                |           ...
                |          Set iObj4=objThisIntf.CreateGroup (iobj1,iStrVar2,iStrVar3
                |          )

        :param Product i_current_product:
        :param str i_group_type:
        :param str i_group_id:
        :rtype: PSPGroup
        """
        return PSPGroup(self.psp_app_factory.CreateGroup(i_current_product.com_object, i_group_type, i_group_id))

    def delete_compartment(self, i_compartment: PSPGroup) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub DeleteCompartment(PspGroup iCompartment)
                | 
                |     Delete a compartment instance.
                | 
                |     Parameters:
                | 
                |         iCompartment
                |             Compartment to be deleted 
                | 
                |     Example:
                | 
                |          Dim objThisIntf As PspAppFactory
                |          Dim iobj1 As PspGroup
                |           ...
                |          objThisIntf.DeleteCompartment iobj1

        :param PSPGroup i_compartment:
        :rtype: None
        """
        return self.psp_app_factory.DeleteCompartment(i_compartment.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'delete_compartment'
        # # vba_code = """
        # # Public Function delete_compartment(psp_app_factory)
        # #     Dim iCompartment (2)
        # #     psp_app_factory.DeleteCompartment iCompartment
        # #     delete_compartment = iCompartment
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def delete_group(self, i_group: PSPGroup) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub DeleteGroup(PspGroup iGroup)
                | 
                |     Delete a group.
                | 
                |     Parameters:
                | 
                |         iGroup
                |             Group to be deleted. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspAppFactory
                |          Dim iobj1 As PspGroup
                |           ...
                |          objThisIntf.DeleteGroup iobj1

        :param PSPGroup i_group:
        :rtype: None
        """
        return self.psp_app_factory.DeleteGroup(i_group.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'delete_group'
        # # vba_code = """
        # # Public Function delete_group(psp_app_factory)
        # #     Dim iGroup (2)
        # #     psp_app_factory.DeleteGroup iGroup
        # #     delete_group = iGroup
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def delete_logical_line(self, i_logical_line: PSPLogicalLine) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub DeleteLogicalLine(PspLogicalLine iLogicalLine)
                | 
                |     Delete a logical line instance.
                | 
                |     Parameters:
                | 
                |         iLogicalLine
                |             Logical Line to be deleted 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspAppFactory
                |          Dim iobj1 As PspLogicalLine
                |           ...
                |          objThisIntf.DeleteLogicalLine iobj1

        :param PSPLogicalLine i_logical_line:
        :rtype: None
        """
        return self.psp_app_factory.DeleteLogicalLine(i_logical_line.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'delete_logical_line'
        # # vba_code = """
        # # Public Function delete_logical_line(psp_app_factory)
        # #     Dim iLogicalLine (2)
        # #     psp_app_factory.DeleteLogicalLine iLogicalLine
        # #     delete_logical_line = iLogicalLine
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def delete_part(self, i_part: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub DeletePart(Product iPart)
                | 
                |     Delete a part.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             Part to be deleted. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspAppFactory
                |          Dim iobj1 As Product
                |           ...
                |          objThisIntf.DeletePart iobj1

        :param Product i_part:
        :rtype: None
        """
        return self.psp_app_factory.DeletePart(i_part.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'delete_part'
        # # vba_code = """
        # # Public Function delete_part(psp_app_factory)
        # #     Dim iPart (2)
        # #     psp_app_factory.DeletePart iPart
        # #     delete_part = iPart
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_compartment(self, i_current_product: Product, i_compartment_id: str) -> PSPGroup:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCompartment(Product iCurrentProduct,
                | CATBSTR iCompartmentID) As PspGroup
                | 
                |     Instanciate a compartment from the catalog into the current
                |     Product.
                | 
                |     Parameters:
                | 
                |         iCurrentProduct
                |             The current Product into which a compartment will be instanciated.
                |             
                |         iCompartmentID
                |             Compartment ID to get from the compartment catalog.
                |
                |     Returns:
                |         Compartment instance. 
                |     Example:
                |
                |          Dim objThisIntf As PspAppFactory
                |          Dim iobj1 As Product
                |          Dim iStrVar2 As String
                |          Dim iObj3 As PspGroup
                |           ...
                |          Set iObj3=objThisIntf.GetCompartment (iobj1,iStrVar2
                |          )

        :param Product i_current_product:
        :param str i_compartment_id:
        :rtype: PSPGroup
        """
        return PSPGroup(self.psp_app_factory.GetCompartment(i_current_product.com_object, i_compartment_id))

    def get_logical_line(self, i_current_product: Product, i_logical_line_id: str) -> PSPLogicalLine:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetLogicalLine(Product iCurrentProduct,
                | CATBSTR iLogicalLineID) As PspLogicalLine
                | 
                |     Returns a PspLogicalLine Logical line Instance.
                | 
                |     Parameters:
                | 
                |         iCurrentProduct
                |             The current Product into which a logical line will be instanciated.
                |             
                |         iLogicalLineID
                |             Logical line ID to get from the logical line catalog.
                |
                |     Returns:
                |         Logical line instance. 
                |
                |     Example:
                |
                |          Dim objThisIntf As PspAppFactory
                |          Dim iobj1 As Product
                |          Dim iStrVar2 As String
                |           ...
                |          objThisIntf.GetLogicalLine (iobj1,iStrVar2 )

        :param Product i_current_product:
        :param str i_logical_line_id:
        :rtype: PSPLogicalLine
        """
        return PSPLogicalLine(self.psp_app_factory.GetLogicalLine(i_current_product.com_object, i_logical_line_id))

    def list_compartments(self, i_current_product: Product) -> PSPListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListCompartments(Product iCurrentProduct) As
                | PspListOfObjects
                | 
                |     Retrieves a list of Compartments in the current Product.
                | 
                |     Parameters:
                | 
                |         iCurrentProduct
                |             The current Product to query. 
                | 
                |     Returns:
                |         A list of Compartmemts ( A list of CATIAPspGroup) 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As PspAppFactory
                |          Dim iobj1 As Product
                |          Dim objArg2 As PspListOfObjects
                |          
                |           ...
                |          Set ObjArg2 = objThisIntf.ListCompartments (iobj1 )

        :param Product i_current_product:
        :rtype: PSPListOfObjects
        """
        return PSPListOfObjects(self.psp_app_factory.ListCompartments(i_current_product.com_object))

    def list_groups(self, i_current_product: Product) -> PSPListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListGroups(Product iCurrentProduct) As
                | PspListOfObjects
                | 
                |     Retrieve a list of Groups in the current Product.
                | 
                |     Parameters:
                | 
                |         iCurrentProduct
                |             The current Product to query.. 
                | 
                |     Returns:
                |         A list of Groups ( A list of CATIAPspGroup)
                |
                |     Example:
                |
                |          Dim objThisIntf As PspAppFactory
                |          Dim iobj1 As Product
                |          Dim objArg2 As ListOfObjects
                |           ...
                |          Set ObjArg2 = objThisIntf.ListGroups (iobj1)

        :param Product i_current_product:
        :rtype: PSPListOfObjects
        """
        return PSPListOfObjects(self.psp_app_factory.ListGroups(i_current_product.com_object))

    def list_logical_lines(self, i_current_product: Product) -> PSPListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListLogicalLines(Product iCurrentProduct) As
                | PspListOfObjects
                | 
                |     Returns a list of logical lines in the current Product.
                | 
                |     Parameters:
                | 
                |         iCurrentProduct
                |             The current Product to query.. 
                | 
                |     Returns:
                |         A list of logical Lines (A list of PspLogicalLine)
                |
                |     Example:
                |
                |          Dim objThisIntf As PspAppFactory
                |          Dim iobj1 As Product
                |          Dim objArg2 As PspListOfObjects
                |          
                |           ...
                |          Set ObjArg2 = objThisIntf.ListLogicalLines (iobj1 )

        :param Product i_current_product:
        :rtype: PSPListOfObjects
        """
        return PSPListOfObjects(self.psp_app_factory.ListLogicalLines(i_current_product.com_object))

    def list_physicals(self, i_current_product: Product, i_domain_id: int) -> PSPListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListPhysicals(Product iCurrentProduct,
                | CatPspIDLDomainID iDomainID) As PspListOfObjects
                | 
                |     Returns a list of Physical objects in the node.
                | 
                |     Parameters:
                | 
                |         iCurrentProduct
                |             The current Product to query. 
                |         iDomainID
                |             Physical objects that have this domain ID. To get list of all in
                |             all domains set iDomainID= catPspIDLNone. 
                | 
                |     Returns:
                |         A list of physical objects (A list of PspPhysical objects)
                |         
                |     Example:
                |
                |          Dim objThisIntf As PspAppFactory
                |          Dim iobj1 As Product
                |          Dim iobjArg2 As CatPspIDLDomainID
                |          Dim objArg3 As PspListOfObjects
                |           ...
                |          Set ObjArg3 = objThisIntf.ListPhysicals (iobj1, iobjArg2 )

        :param Product i_current_product:
        :param int i_domain_id: enum cat_psp_idl_domain_id
        :rtype: PSPListOfObjects
        """
        return PSPListOfObjects(self.psp_app_factory.ListPhysicals(i_current_product.com_object, i_domain_id))

    def __repr__(self):
        return f'PSPAppFactory(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.in_interfaces.document import Document
from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.cat_smarteam_integ_interfaces.sti_db_children import StiDBChildren


class StiDBItem(AnyObject):
    """

    .. note::
        :class: toggle

        CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

            | System.IUnknown
            |     System.IDispatch
            |         System.CATBaseUnknown
            |             System.CATBaseDispatch
            |                 System.AnyObject
            |                     StiDBItem
            |
            | Represents the SmarTeam Integration Object, that is to say the Document coming
            | from SmarTeam database.
            | Role: It retrieves SmarTeam Document information. It is managed by
            | StiEngine.
            |
            | See also:
            |     StiEngine
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sti_db_item = com_object

    def get_children(self) -> 'StiDBChildren':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetChildren() As StiDBChildren
                | 
                |     Returns both all the Children of the CATIA Document -associated to the
                |     CATIAStiDBItem- and their corresponding Link Types with their Father CATIA
                |     Document.
                | 
                |     See also:
                |         StiDBChildren 
                |     Returns:
                |         This ouptut corresponds to the retrieved CATIAStiDBChildren from the
                |         Father CATIAStiDBItem. 
                |     Example:
                | 
                |           The following example returns in ochildrenList both all the Children
                |           
                |          and their Link Types with their CATIAStiDBItem Father
                |          oStiDBItem.
                |
                |          Dim oStiDBItem As StiDBItem
                |          Dim ochildrenList As StiDBChildren
                |          Set ochildrenList = oStiDBItem.GetChildren
                |          Dim lChildrenNumber As long
                |          lChildrenNumber = ochildrenList.Count
                |          For i = 1 To lChildrenNumber
                |             Dim oChildStiDBItem As StiDBItem
                |             Set oChildStiDBItem = ochildrenList.Item(i)
                |             Dim sChildLinkType As CATBSTR
                |             sChildLinkType = ochildrenList.LinkType(i)
                |          Next

        :rtype: StiDBChildren
        """

        from pycatia.cat_smarteam_integ_interfaces.sti_db_children import StiDBChildren
        return StiDBChildren(self.sti_db_item.GetChildren())

    def get_document(self) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDocument() As Document
                | 
                |     Returns the CATIA Document associated to the CATIAStiDBItem -the SmarTeam
                |     Integration Object.
                | 
                |     Returns:
                |         This ouptut corresponds to the retrieved CATIA Document.
                |         
                |     Example:
                | 
                |           The following example returns in oDocument the CATIA Document
                |           corresponding to 
                |          the CATIAStiDBItem oStiDBItem.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim oStiDBItem As StiDBItem
                |          Set oStiDBItem = oStiEngine.GetStiDBItemFromCATBSTR("E:/CATIAFiles/Engine.CATProduct")
                |          Dim oDocument As Document
                |          Set oDocument = oStiDBItem.GetDocument

        :rtype: Document
        """
        return Document(self.sti_db_item.GetDocument())

    def get_document_full_path(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDocumentFullPath() As CATBSTR
                | 
                |     Returns the Full Path of the CATIA Document associated to the
                |     CATIAStiDBItem.
                | 
                |     Returns:
                |         This ouptut corresponds to the retrieved Full Path of the
                |         CATIAStiDBItem. 
                |     Example:
                | 
                |           The following example returns in oFullPath the full path
                |           corresponding to 
                |          the CATIAStiDBItem oStiDBItem.
                |
                |          Dim oStiDBItem As StiDBItem
                |          Dim oFullPath As string
                |          oFullPath = oStiDBItem.GetDocumentFullPath

        :rtype: str
        """
        return self.sti_db_item.GetDocumentFullPath()

    def is_cfo_type(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsCFOType() As boolean
                | 
                |     Returns if the CATIA Document -associated to the CATIAStiDBItem- is a
                |     Component File or not.
                | 
                |     Returns:
                |         This ouptut corresponds to the boolean 'oIsCFOType'. 'oIsCFOType' is
                |         True when the CATIAStiDBItem is a Component File, False otherwise.
                |         
                |     Example:
                | 
                |           The following example tests if the CATIAStiDBItem is a Component
                |           File.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          (...)
                |          Dim oIsCFOType As boolean
                |          oIsCFOType = oStiEngine.IsCFOType

        :rtype: bool
        """
        return self.sti_db_item.IsCFOType()

    def is_root(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsRoot() As boolean
                | 
                |     Returns if the CATIA Document -associated to the CATIAStiDBItem- is a Root.
                |     This method returns True if the Document is a Root, False
                |     otherwise.
                | 
                |     Returns:
                |         This ouptut corresponds to the boolean 'oIsRootCFO'. 
                |     Example:
                | 
                |           The following example tests if the CATIAStiDBItem is a Root component
                |           file.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          (...)
                |          Dim oIsRootCFO As boolean
                |          oIsRootCFO = oStiEngine.IsRoot

        :rtype: bool
        """
        return self.sti_db_item.IsRoot()

    def __repr__(self):
        return f'StiDBItem(name="{self.name}")'
